@@ -1 +1,4 @@
+"""
+Exceptions
+"""
 from sqllex.exceptions.sqlExceptions import *
